import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import {
  csv,
  arc,
  pie,
  scaleBand,
  scaleLinear,
  max,
} from 'd3';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';

const width = window.innerWidth;
const height = window.innerHeight;
const margin = {
  top: 20,
  right: 20,
  bottom: 20,
  left: 200,
};
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;

const App = () => {
  const data = useData();

  if (!data) {
    return <pre>Loading...</pre>;
  }
  console.log(data[0]);
  
  const xValue = d => d.Population;

  const xScale = scaleLinear()
    .domain([0, max(data, xValue)])
    .range([0, innerWidth]);

  const yValue = d => d.Country;

  const yScale = scaleBand()
    .domain(data.map(yValue))
    .range([0, innerHeight]);

  return (
    <svg width={width} height={height}>
      <g
        className="tick"
        transform={`translate(${margin.left}, ${margin.top})`}
      >
        <AxisBottom
          xScale={xScale}
          innerHeight={innerHeight}
        />
        <AxisLeft yScale={yScale} />
        <Marks
          data={data}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
        />
      </g>
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
